/*
 * ifselshowthis JQuery Plugin
 *
 * If input selected (RADIO, CHECKBOX or SELECT) show this class of the selected item 
 * and hides the class of the non selected items (RADIO, SELECT)
 *
 */

;(function ( $, window, document, undefined ) {

      // undefined is used here as the undefined global variable in ECMAScript 3 is
      // mutable (ie. it can be changed by someone else). undefined isn't really being
      // passed in so we can ensure the value of it is truly undefined. In ES5, undefined
      // can no longer be modified.

      // window and document are passed through as local variable rather than global
      // as this (slightly) quickens the resolution process and can be more efficiently
      // minified (especially when both are regularly referenced in your plugin).

      // Create the defaults once
      var pluginName = "ifselshowthis",
            defaults = {
            propertyName: "value"
      };

      // The actual plugin constructor
      function Plugin ( element, options ) {
            this.element = element;
            // jQuery has an extend method which merges the contents of two or
            // more objects, storing the result in the first object. The first object
            // is generally empty as we don't want to alter the default options for
            // future instances of the plugin
            this.settings = $.extend( {}, defaults, options );
            this._defaults = defaults;
            this._name = pluginName;
            this.init();
      }

      Plugin.prototype = {
            init: function () {
                  // Place initialization logic here
                  // You already have access to the DOM element and
                  // the options via the instance, e.g. this.element
                  // and this.settings
                  // you can add more functions like the one below and
                  // call them like so: this.yourOtherFunction(this.element, this.settings).
                  
                  if(this.element.type == "radio") {
                     // Setup the event for the elements
                     $(this.element).on("change", $.proxy(this.radioOnChange, this));
                     // Now see if element is selected
                     this.showThat($(this.element));
                  }
                  else if(this.element.type == "select-one") {
                     // Setup the event for the elements
                     $(this.element).on("change", $.proxy(this.selectOnChange, this));
                     // Now see if element is selected
                     this.showThat($(this.element));
                  }
            },
            
            radioOnChange: function (e) {

               var name = $(this.element).attr("name");
               var that = this;
               // Go through all the radios in the group and call showThat on them
               $("input[type=radio][name='" + name + "']").each(function() {
                  that.showThat($(this));
               });
               
            },
            
            selectOnChange: function (e) {
               this.showThat($(this.element));				
            },
            
            isSelected: function (element) {
               
               if(element[0].type == "radio" && element.is(":checked"))
                  return true;
                  
               else if (element[0].type == "select-one") {
                  var selVal = element.data("ifsel-show-this-val");
                  
                  if($.type(selVal) == "array") {
                     var length = selVal.length,
                         eVal = element.val();
                     for (var i = 0; i < length; i++) 
                       if(selVal[i] == eVal)
                          return true;
                  }
                  else {
                     if(selVal == element.val())
                        return true;
                  }
               }
                  
               return false;
            },
            
            showThat: function (element) {
               
               var _ifselshowthis = element.data("ifsel-show-this");
               
               if(this.isSelected(element))
                  $(_ifselshowthis).show("slow");
               else
                  $(_ifselshowthis).hide("slow");  
            }

      };

      // A really lightweight plugin wrapper around the constructor,
      // preventing against multiple instantiations
      $.fn[ pluginName ] = function ( options ) {
            return this.each(function() {
                  if ( !$.data( this, "plugin_" + pluginName ) ) {
                        $.data( this, "plugin_" + pluginName, new Plugin( this, options ) );
                  }
            });
      };

})( jQuery, window, document );
