(function($) {
    var index = -1;
    var $form, $steps;
    var keys = [];

    var settings = {
        'ajaxCallback': null,

        'actions': {
            'submit': 'default'
        },

        'events': {
            'change': null,
            'next': null,
            'previous': null,
            'submit': null,
            'reset': null
        },

        'shortcuts': {
            'next': [],
            'previous': [],
            'reset': [27]
        },
        'startStep': 0
    };

    var methods = {
        'next': function(ignoreEvents) {
            var next = index + 1;

            if(pmethods.eventIsSet('next', ignoreEvents)) {
                if(settings.events.next.call(this, next) === false) return;
            }

            if(next === $steps.length) methods.submit();
            else methods.show(next);
        },

        'previous': function(ignoreEvents) {
            var next = index - 1;
            if(next < 0) next = 0;
            
            if(pmethods.eventIsSet('previous', ignoreEvents)) {
                if(settings.events.previous.call(this, next) === false) return;
            }

            methods.show(next);
        },

        'show': function(i, ignoreEvents) {
            var step, field, bar;

//            if(pmethods.eventIsSet('previous', ignoreEvents)) {
//                if(settings.events.previous.call(this, i) === false) return;
//            }

            step = $steps.eq(index);
            bar = step.data('bar');
            field = pmethods.getField(step);

            step.hide();
            bar.hide();
            field.blur();

            if(i < $steps.length) {
                step = $steps.eq(i);
                bar = step.data('bar');
                field = pmethods.getField(step);

                step.show();
                bar.show();
                field.focus();
            }

            index = i;
        },

        'submit': function(ignoreEvents) {
            if(pmethods.eventIsSet('submit', ignoreEvents)) {
                var sFields = $steps.find('input, textarea, select');
                if(settings.events.submit.call(this, sFields) === false) return;
            }

            if(settings.actions.submit && settings.actions.submit === 'default') {
                $form.submit();
            } else if(settings.actions.submit && settings.actions.submit === 'ajax') {
                var url = $form.attr('action');
                var fields = {'ajax': true};

                $form.find('input, textarea, select').each(function(i, e) {
                    var name = $(e).attr('name');
                    var value = $(e).val();

                    if(typeof name === 'string' && name.length <= 0) return;

                    fields[name] = value;
                });

                $.ajax({
                    'cache': false,
                    'complete': settings.ajaxCallback,
                    'data': fields,
                    'type': 'POST',
                    'url': url
                });
            }
        },

        'reset': function(ignoreEvents) {
            methods.show(0);

            $steps.find('input').each(pmethods.resetInput);
            $steps.find('textarea').each(pmethods.resetTextarea);
            $steps.find('select').each(pmethods.resetSelect);

            if(pmethods.eventIsSet('reset', ignoreEvents)) {
                settings.events.reset.call(this);
            }
        }
    };

    var pmethods = {
        'init': function(opt) {
            $.extend(settings, opt);

            $form = this;
            $steps = this.find('.wizzard-step');
            $form.addClass('wizzard');
            $form.removeClass('non-wizzard');

            $steps.hide().each(function(i, e) {
                var $e = $(e);
                var field = pmethods.getField($e);
                var bar = $(this).prev( '.wizzard-step-bar' );
                $(this).data('bar', bar);
            });

            if($steps.length > 0) {
                methods.show(parseInt(settings.startStep));
            }
        },

        'resetInput': function(i, e) {
            var $e = $(e);
            $e.val($e.attr('value'));
        },

        'resetTextarea': function(i, e) {
            var $e = $(e);
            $e.val($e.html());
        },

        'resetSelect': function(i, e) {
            var $e = $(e);
            var val = $e.find('option[selected]').attr('value');
            $e.val(val);
        },

        'getField': function(e) {
            var tag = e.prop('nodeName').toLowerCase();
            var desc = e.find('input, textarea, select');

            if(tag === 'input' || tag === 'textarea' || tag === 'select') return e;
            return desc;
        },

        'eventIsSet': function(name, ignoreEvents) {
            return (!ignoreEvents && settings.events && settings.events[name] && typeof settings.events[name] === 'function');
        }
    };

    $.fn.towizzard = function(opt) {
        if(methods[opt]) {
            return methods[opt].apply(this, Array.prototype.slice.call(arguments, 1));
        } else if (typeof opt === 'object' || !opt) {
            return pmethods.init.apply(this, arguments);
        }

        return this;
    };
})(jQuery);
