<?php

class highestRatedVideos extends WP_Widget {

   /** constructor */
   function __construct () {
      parent::__construct(false, 'Highest Rated Videos', array('description' => 'Use this widget to show the highest rated videos'));
   }

   /** @see WP_Widget::widget */
   function widget($args, $instance) {
      extract( $args );
      $title = apply_filters( 'widget_title', empty( $instance['title'] ) ? __( 'Highest Rated Videos' ) : $instance['title'], $instance, $this->id_base );
      $no_videos = $instance['no_videos'];
      $show_views = $instance['show_views'];
      $show_rating = $instance['show_rating'];
      $show_user = $instance['show_user'];

      echo $before_widget;
      if ( $title )
         echo $before_title . $title . $after_title;

      if(!$no_videos)
         $no_videos = 5;

      $args = array( 'showposts' => $no_videos, 'orderby' => 'meta_value_num','meta_key' => '_imwb_videopress_post_video_rating', 'order' => 'DESC' );
      $query = new WP_Query( $args );

      if ($query->have_posts()) : while ($query->have_posts()) : $query->the_post();
?>
         <div class="video_content">
         <div class="video_thumb">
              <a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>" <?php echo (imwb_videopress_get_option('videothumbnw') == 'Y' ? ' target="_blank"' : '')?> >
           <?php imwb_videopress_the_post_thumbnail(get_the_ID(), '110px', '80px'); ?>
           </a>
         </div>
         <div class="video_text">
          <div class="title">
           <a href="<?php the_permalink() ?>" rel="bookmark" title="<?php the_title_attribute(); ?>"><?php echo get_the_title() ?></a>
           <?php if($show_user) { ?>
           <br>
           <span>by <?php the_author(); ?></span>
           <?php } ?>
          </div>
          <div class="stats">
<?php
$rClass = " left";
if($show_views) {
$rClass = " right";
?>
            <div class="views left"><?php imwb_videopress_views_number("no views", "one view", "% views"); ?></div>
<?php } if($show_rating) { ?>
          <div class="widget_rating<?php echo $rClass;?>" data-average="<?php echo imwb_videopress_get_rating();?>" data-id="<?php echo get_the_ID();?>"></div>
<?php } ?>
          </div>
        </div>
      </div>
      <?php endwhile; endif;

      // Reset Post Data
      wp_reset_postdata();

      echo $after_widget;

   }

   /** @see WP_Widget::update */
   function update($new_instance, $old_instance) {
      $instance = $old_instance;
      $instance['title'] = strip_tags($new_instance['title']);
      $instance['no_videos'] = strip_tags($new_instance['no_videos']);
      $instance['show_views'] = strip_tags($new_instance['show_views']);
      $instance['show_rating'] = strip_tags($new_instance['show_rating']);
      $instance['show_user'] = strip_tags($new_instance['show_user']);
      return $instance;
   }

   /** @see WP_Widget::form */
   function form($instance) {
      $title = esc_attr(isset($instance['title']) ? $instance['title'] : 'Highest Rated Videos');
      $no_videos = esc_attr(isset($instance['no_videos']) ? $instance['no_videos'] : 5);
      $show_views = esc_attr(isset($instance['show_views']) ? $instance['show_views'] : 'Y');
      $show_rating = esc_attr(isset($instance['show_rating']) ? $instance['show_rating'] : 'Y');
      $show_user = esc_attr(isset($instance['show_user']) ? $instance['show_user'] : 'Y');
     ?>
     <p><label for="<?php echo $this->get_field_id('title'); ?>">
     <?php _e('Title:'); ?>
     <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></label></p>

     <p><label for="<?php echo $this->get_field_id('no_videos'); ?>">
     <?php _e('No of Videos:'); ?>
     <input class="widefat" id="<?php echo $this->get_field_id('no_videos'); ?>" name="<?php echo $this->get_field_name('no_videos'); ?>" type="text" value="<?php echo $no_videos; ?>" /></label></p>

   <p><label for="<?php echo $this->get_field_id('show_user'); ?>">
       <?php _e('Show "by user":'); ?>
       <input type="checkbox" id="<?php echo $this->get_field_id('show_user'); ?>" name="<?php echo $this->get_field_name('show_user'); ?>" <?php if($show_user) : ?> checked="checked" <?php endif ?> /></label></p>

  <p><label for="<?php echo $this->get_field_id('show_views'); ?>">
         <?php _e('Show View Count:'); ?>
         <input type="checkbox" id="<?php echo $this->get_field_id('show_views'); ?>" name="<?php echo $this->get_field_name('show_views'); ?>" <?php if($show_views) : ?> checked="checked" <?php endif ?> /></label></p>
   <p><label for="<?php echo $this->get_field_id('show_rating'); ?>">
       <?php _e('Show Rating:'); ?>
       <input type="checkbox" id="<?php echo $this->get_field_id('show_rating'); ?>" name="<?php echo $this->get_field_name('show_rating'); ?>" <?php if($show_rating) : ?> checked="checked" <?php endif ?> /></label></p>


   <?php
   }

}

class mostViewedVideos extends WP_Widget {

   /** constructor */
   function __construct () {
      parent::__construct(false, 'Most Viewed Videos', array('description' => 'Use this widget to show the most viewed videos'));
   }

   /** @see WP_Widget::widget */
   function widget($args, $instance) {
      extract( $args );
      $title = apply_filters( 'widget_title', empty( $instance['title'] ) ? __( 'Most Viewed Videos' ) : $instance['title'], $instance, $this->id_base );
      $no_videos = $instance['no_videos'];
      $show_views = $instance['show_views'];
      $show_rating = $instance['show_rating'];
      $show_user = $instance['show_user'];

      echo $before_widget;
      if ( $title )
         echo $before_title . $title . $after_title;

      if(!$no_videos)
         $no_videos = 5;

      $args = array( 'showposts' => $no_videos, 'orderby' => 'meta_value_num','meta_key' => '_imwb_videopress_post_video_views', 'order' => 'DESC' );
      $query = new WP_Query( $args );

      if ($query->have_posts()) : while ($query->have_posts()) : $query->the_post();
?>
         <div class="video_content">
         <div class="video_thumb">
              <a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>" <?php echo (imwb_videopress_get_option('videothumbnw') == 'Y' ? ' target="_blank"' : '')?> >
           <?php imwb_videopress_the_post_thumbnail(get_the_ID(), '110px', '80px'); ?>
           </a>
         </div>
         <div class="video_text">
          <div class="title">
           <a href="<?php the_permalink() ?>" rel="bookmark" title="<?php the_title_attribute(); ?>"><?php echo get_the_title() ?></a>
           <?php if($show_user) { ?>
           <br>
           <span>by <?php the_author(); ?></span>
           <?php } ?>
          </div>
          <div class="stats">
<?php $rClass = " left";
if($show_views) {
$rClass = " right"; ?>
          <div class="views left"><?php imwb_videopress_views_number("no views", "one view", "% views"); ?></div>
<?php } if($show_rating) { ?>
            <div class="widget_rating<?php echo $rClass;?>" data-average="<?php echo imwb_videopress_get_rating();?>" data-id="<?php echo get_the_ID();?>"></div>
<?php } ?>
          </div>
        </div>
      </div>
      <?php endwhile; endif;

      // Reset Post Data
      wp_reset_postdata();

      echo $after_widget;

   }

   /** @see WP_Widget::update */
   function update($new_instance, $old_instance) {
      $instance = $old_instance;
      $instance['title'] = strip_tags($new_instance['title']);
      $instance['no_videos'] = strip_tags($new_instance['no_videos']);
      $instance['show_views'] = strip_tags($new_instance['show_views']);
      $instance['show_rating'] = strip_tags($new_instance['show_rating']);
      $instance['show_user'] = strip_tags($new_instance['show_user']);
      return $instance;
   }

   /** @see WP_Widget::form */
   function form($instance) {
      $title = esc_attr(isset($instance['title']) ? $instance['title'] : 'Most Viewed Videos');
      $no_videos = esc_attr(isset($instance['no_videos']) ? $instance['no_videos'] : '5');
      $show_views = esc_attr(isset($instance['show_views']) ? $instance['show_views'] : 'Y');
      $show_rating = esc_attr(isset($instance['show_rating']) ? $instance['show_rating'] : 'Y');
      $show_user = esc_attr(isset($instance['show_user']) ? $instance['show_user'] : 'Y');

     ?>

     <p><label for="<?php echo $this->get_field_id('title'); ?>">
     <?php _e('Title:'); ?>
     <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></label></p>

     <p><label for="<?php echo $this->get_field_id('no_videos'); ?>">
     <?php _e('No of Videos:'); ?>
     <input class="widefat" id="<?php echo $this->get_field_id('no_videos'); ?>" name="<?php echo $this->get_field_name('no_videos'); ?>" type="text" value="<?php echo $no_videos; ?>" /></label></p>

   <p><label for="<?php echo $this->get_field_id('show_user'); ?>">
       <?php _e('Show "by user":'); ?>
       <input type="checkbox" id="<?php echo $this->get_field_id('show_user'); ?>" name="<?php echo $this->get_field_name('show_user'); ?>" <?php if($show_user) : ?> checked="checked" <?php endif ?> /></label></p>
   <p><label for="<?php echo $this->get_field_id('show_views'); ?>">
      <?php _e('Show View Count:'); ?>
      <input type="checkbox" id="<?php echo $this->get_field_id('show_views'); ?>" name="<?php echo $this->get_field_name('show_views'); ?>" <?php if($show_views) : ?> checked="checked" <?php endif ?> /></label></p>

    <p><label for="<?php echo $this->get_field_id('show_rating'); ?>">
       <?php _e('Show Rating:'); ?>
       <input type="checkbox" id="<?php echo $this->get_field_id('show_rating'); ?>" name="<?php echo $this->get_field_name('show_rating'); ?>" <?php if($show_rating) : ?> checked="checked" <?php endif ?> /></label></p>

   <?php
   }

}

class relatedVideos extends WP_Widget {

   /** constructor */
   function __construct () {
      parent::__construct(false, 'Related Videos', array('description' => 'Use this widget to show videos related to the current entry'));
   }

   /** @see WP_Widget::widget */
   function widget($args, $instance) {
      global $wpdb, $post;

      if(!$post->ID){return;}

      extract( $args );
      $title = apply_filters( 'widget_title', empty( $instance['title'] ) ? __( 'Related Videos' ) : $instance['title'], $instance, $this->id_base );
      $no_videos = $instance['no_videos'];
      $show_rating = $instance['show_rating'];
      $show_views = $instance['show_views'];
      $show_user = $instance['show_user'];
      $no_rel_posts = $instance['no_rel_posts'];
      $no_rel_text = $instance['no_rel_text'];

      if(!$no_videos) $no_videos = 5;
      if(!$no_rel_posts) {
         $no_rel_posts = 'T';
         $no_rel_text = 'No Related Videos';
      }

      echo $before_widget;
      if ( $title )
         echo $before_title . $title . $after_title;

      $now = current_time('mysql', 1);
      $tags = wp_get_post_tags($post->ID);
   	if(!empty($tags))
   	   $taglist = "'" . $tags[0]->term_id. "'";
   	else
         $taglist = "''";

   	$tagcount = count($tags);
   	if ($tagcount > 1) {
   		for ($i = 1; $i < $tagcount; $i++) {
   			$taglist .= ", '" . $tags[$i]->term_id . "'";
   		}
   	}

   	$query = "SELECT p.ID, p.post_title, p.post_content,p.post_excerpt, p.post_date,  p.comment_count, count(t_r.object_id) as cnt, u.display_name as author FROM $wpdb->term_taxonomy t_t, $wpdb->term_relationships t_r, $wpdb->posts p , $wpdb->users u WHERE t_t.taxonomy ='post_tag' AND t_t.term_taxonomy_id = t_r.term_taxonomy_id AND t_r.object_id  = p.ID AND (t_t.term_id IN ($taglist)) AND p.ID != $post->ID AND p.post_status = 'publish' AND p.post_date_gmt < '$now' AND p.post_author = u.ID GROUP BY t_r.object_id ORDER BY cnt DESC, p.post_date_gmt DESC LIMIT $no_videos;";

  		$related_posts = $wpdb->get_results($query);

  		if (!$related_posts){
  		   if ($no_rel_posts == 'T') {
?>
  		   <div class="video_content"><div class="title"><?php echo wptexturize($no_rel_text) ?></div></div>
<?php
  		   }
  		   else {
  		      $query = "SELECT p.ID, post_title, post_content,post_excerpt, post_date, comment_count, u.display_name as author FROM $wpdb->posts p, $wpdb->users u WHERE post_status = 'publish' AND post_type = 'post' AND post_date_gmt < '$now' AND p.ID != $post->ID AND p.post_author = u.ID ORDER BY RAND() LIMIT $no_videos;";

  		       $related_posts = $wpdb->get_results($query);
  		   }
  		}

      foreach ($related_posts as $related_post ){
?>
         <div class="video_content">
         <div class="video_thumb">
              <a href="<?php echo get_permalink($related_post->ID); ?>" title="<?php echo wptexturize($related_post->post_title); ?>" <?php echo (imwb_videopress_get_option('videothumbnw') == 'Y' ? ' target="_blank"' : '')?> >
           <?php imwb_videopress_the_post_thumbnail($related_post->ID, '110px', '80px'); ?>
           </a>
         </div>
         <div class="video_text">
          <div class="title">
           <a href="<?php echo get_permalink($related_post->ID) ?>" rel="bookmark" title="<?php echo wptexturize($related_post->post_title); ?>"><?php echo $related_post->post_title ?></a>
           <?php if($show_user) { ?>
           <br>
           <span>by <?php echo wptexturize($related_post->author) ?></span>
           <?php } ?>
          </div>
          <div class="stats">
<?php
$rClass = " left";
if($show_views) {
$rClass = " right";
?>
            <div class="views left"><?php imwb_videopress_views_number("no views", "one view", "% views", $related_post->ID); ?></div>
          <?php }
           if($show_rating) { ?>
            <div class="widget_rating<?php echo $rClass;?>" data-average="<?php echo imwb_videopress_get_rating();?>" data-id="<?php echo get_the_ID();?>"></div>
          <?php } ?>
          </div>
        </div>
      </div>
      <?php }

      // Reset Post Data
      wp_reset_postdata();

      echo $after_widget;

   }

   /** @see WP_Widget::update */
   function update($new_instance, $old_instance) {
      $instance = $old_instance;
      $instance['title'] = strip_tags($new_instance['title']);
      $instance['no_videos'] = strip_tags($new_instance['no_videos']);
      $instance['show_rating'] = strip_tags($new_instance['show_rating']);
      $instance['show_views'] = strip_tags($new_instance['show_views']);
      $instance['show_user'] = strip_tags($new_instance['show_user']);
      $instance['no_rel_posts'] = strip_tags($new_instance['no_rel_posts']);
      $instance['no_rel_text'] = strip_tags($new_instance['no_rel_text']);
      return $instance;
   }

   /** @see WP_Widget::form */
   function form($instance) {
      $title = esc_attr(isset($instance['title']) ? $instance['title'] : 'Related Videos');
      $no_videos = esc_attr(isset($instance['no_videos']) ? $instance['no_videos'] : '5');
      $show_rating = esc_attr(isset($instance['show_rating']) ? $instance['show_rating'] : 'Y');
      $show_views = esc_attr(isset($instance['show_views']) ? $instance['show_views'] : 'Y');
      $show_user = esc_attr(isset($instance['show_user']) ? $instance['show_user'] : 'Y');
      $no_rel_posts = esc_attr(isset($instance['no_rel_posts']) ? $instance['no_rel_posts'] : 'T');
      $no_rel_text = esc_attr(isset($instance['no_rel_text']) ? $instance['no_rel_text'] : 'No Related Videos');

      if(!$no_rel_posts) {
         $no_rel_posts = 'T';
         $no_rel_text = 'No Related Videos';
      }
     ?>

     <p><label for="<?php echo $this->get_field_id('title'); ?>">
     <?php _e('Title:'); ?>
     <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></label></p>

     <p><label for="<?php echo $this->get_field_id('no_videos'); ?>">
     <?php _e('No of Videos:'); ?>
     <input class="widefat" id="<?php echo $this->get_field_id('no_videos'); ?>" name="<?php echo $this->get_field_name('no_videos'); ?>" type="text" value="<?php echo $no_videos; ?>" /></label></p>

   <p><label for="<?php echo $this->get_field_id('show_user'); ?>">
       <?php _e('Show "by user":'); ?>
       <input type="checkbox" id="<?php echo $this->get_field_id('show_user'); ?>" name="<?php echo $this->get_field_name('show_user'); ?>" <?php if($show_user) : ?> checked="checked" <?php endif ?> /></label></p>

     <p><label for="<?php echo $this->get_field_id('show_rating'); ?>">
            <?php _e('Show Rating:'); ?>
            <input type="checkbox" id="<?php echo $this->get_field_id('show_rating'); ?>" name="<?php echo $this->get_field_name('show_rating'); ?>" <?php if($show_rating) : ?> checked="checked" <?php endif ?> /></label></p>

     <p><label for="<?php echo $this->get_field_id('show_views'); ?>">
             <?php _e('Show Views:'); ?>
             <input type="checkbox" id="<?php echo $this->get_field_id('show_views'); ?>" name="<?php echo $this->get_field_name('show_views'); ?>" <?php if($show_views) : ?> checked="checked" <?php endif ?> /></label></p>
     <p><label for="<?php echo $this->get_field_id('no_rel_posts'); ?>">
             <?php _e('If no related videos, show:'); ?> <br>
             <input type="radio" id="<?php echo $this->get_field_id('no_rel_posts'); ?>" name="<?php echo $this->get_field_name('no_rel_posts'); ?>" <?php if($no_rel_posts == 'T') : ?> checked="checked" <?php endif ?> value="T"/></label> Text
             <input  id="<?php echo $this->get_field_id('no_rel_text'); ?>" name="<?php echo $this->get_field_name('no_rel_text'); ?>" type="text" value="<?php echo $no_rel_text; ?>" /><br>
             <input type="radio" id="<?php echo $this->get_field_id('no_rel_posts'); ?>" name="<?php echo $this->get_field_name('no_rel_posts'); ?>" <?php if($no_rel_posts == 'R') : ?> checked="checked" <?php endif ?> value="R"/></label> Random Videos


    </p>
   <?php
   }

}

register_widget('highestRatedVideos');
register_widget('mostViewedVideos');
register_widget('relatedVideos');

?>
